install_update

Function install_update 

pub fn install_update(
    bin_name: &str,
    current_version: &str,
) -> Result<bool, UpdateError>
Returns true if updated and false if already on the latest release.

Errors

Returns an error when release metadata or the update archive cannot be downloaded, verified, or installed.